@@ -6,8 +6,7 @@ use strict;
 use warnings;
 
 use File::Temp qw( tempfile );
-use IO::Socket::INET;
-use IO::Socket::INET6;
+use IO::Socket::IP;
 use Try::Tiny;
 use Capture::Tiny ':all';
 
@@ -17,11 +16,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.020
+Version 0.021
 
 =cut
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 my $tools = {
     unix => {
@@ -295,15 +294,15 @@ sub _checkIP4 {
     # Now lets try listen on the ip.. see if we can bind to it, try three times on
     # random ports incase we bump into a busy one.
     for (1..3) {
-        my $fail=1;
         my $port = 1025+int(rand(64510));
-        my $sock = IO::Socket::INET->new(
+        my $sock = IO::Socket::IP->new(
+            Domain      =>  PF_INET,
             LocalAddr   =>  $host,
             LocalPort   =>  $port,
             Proto       =>  'tcp',
             ReuseAddr   =>  1
-        ) or $fail = 0;
-        if ($fail) {
+        );
+        if ($sock) {
             $bindsuccess=1;
             last;
         }
@@ -328,7 +327,8 @@ sub _checkIP6 {
     # random ports incase we bump into a busy one.
     for (1..3) {
         my $port = 1025+int(rand(64510));
-        my $sock = IO::Socket::INET6->new(
+        my $sock = IO::Socket::IP->new(
+            Domain      =>  PF_INET6,
             LocalAddr   =>  $host,
             LocalPort   =>  $port,
             Proto       =>  'tcp',
